@@ -504,7 +504,7 @@ filesel_space_update( Filesel *filesel, const char *dirname )
 			char txt[MAX_STRSIZE];
 			VipsBuf buf = VIPS_BUF_STATIC( txt );
 
-			to_size( &buf, sz );
+			vips_buf_append_size( &buf, sz );
 			vips_buf_appendf( &buf, " " );
 			/* Expands to (eg.) '6GB free in "/pics/tmp"'
 			 */
@@ -1122,6 +1122,9 @@ filesel_new( void )
 {
 	Filesel *filesel = (Filesel *) gtk_type_new( TYPE_FILESEL );
 
+	iwindow_set_size_prefs( IWINDOW( filesel ), 
+		"FILESEL_WINDOW_WIDTH", "FILESEL_WINDOW_HEIGHT" );
+
 	return( GTK_WIDGET( filesel ) );
 }
 
