@@ -130,11 +130,32 @@ iimage_edit( GtkWidget *parent, Model *model )
 {
         iImage *iimage = IIMAGE( model );
 
-	if( iimage->value.ii ) {
-		Imageview *iv;
+	if( iimage->value.ii ) 
+		(void) imageview_new( iimage, parent );
+}
 
-		iv = imageview_new( iimage, parent );
-	}
+void
+iimage_header( GtkWidget *parent, Model *model )
+{
+        iImage *iimage = IIMAGE( model );
+	Row *row = HEAPMODEL( iimage )->row;
+	Workspace *ws = row_get_workspace( row );
+
+	GtkWidget *imageheader;
+	char txt[512];
+	VipsBuf buf = VIPS_BUF_STATIC( txt );
+
+	imageheader = imageheader_new( iimage );
+	row_qualified_name_relative( ws->sym, row, &buf );
+	iwindow_set_title( IWINDOW( imageheader ), 
+		_( "Header for \"%s\"" ), vips_buf_all( &buf ) );
+	idialog_set_callbacks( IDIALOG( imageheader ), NULL, NULL, NULL, NULL );
+	idialog_add_ok( IDIALOG( imageheader ), iwindow_true_cb, _( "OK" ) );
+	iwindow_set_parent( IWINDOW( imageheader ), parent );
+	idialog_set_iobject( IDIALOG( imageheader ), IOBJECT( iimage ) );
+	iwindow_build( IWINDOW( imageheader ) );
+
+	gtk_widget_show( imageheader );
 }
 
 static xmlNode *
@@ -398,6 +419,7 @@ iimage_class_init( iImageClass *class )
 
 	model_class->view_new = iimage_view_new;
 	model_class->edit = iimage_edit;
+	model_class->header = iimage_header;
 	model_class->save = iimage_save;
 	model_class->load = iimage_load;
 
