@@ -56,24 +56,15 @@
 #define DEBUG_TIME
  */
 
-/* On quit, make sure we free stuff we can free. Define PROFILE too to get
- * glib's mem use profiler. But it's broken on windows and will cause strange
- * problems, careful.
+/* On quit, make sure we free stuff we can free. 
 #define DEBUG_LEAK
-#define PROFILE
  */
 
 /* Sometimes we need to be able to disable these at build time.
-#undef DEBUG_FATAL
 #undef DEBUG_LEAK
+#undef DEBUG_FATAL
  */
 
-/* Need im__print_all() for leak testing.
- */
-#ifdef DEBUG_LEAK
-extern void im__print_all( void );
-#endif /*DEBUG_LEAK*/
-
 /* General stuff. 
  */
 GdkWindow *main_window_gdk;			/* Top GdkWindow */
@@ -332,8 +323,6 @@ main_quit( void )
 	reduce_destroy( reduce_context );
 
 #ifdef DEBUG_LEAK
-	fprintf( stderr, "DEBUG_LEAK: testing for leaks ...\n" );
-
 	/* Free other GTK stuff.
 	 */
 	if( main_icon_factory )
@@ -357,14 +346,10 @@ main_quit( void )
 	 */
 	UNREF( main_imageinfogroup );
 	heap_check_all_destroyed();
-	im__print_all();
+	vips_shutdown();
 	managed_check_all_destroyed();
 	util_check_all_destroyed();
 	call_check_all_destroyed();
-
-#ifdef PROFILE
-	g_mem_profile();
-#endif /*PROFILE*/
 #endif /*DEBUG_LEAK*/
 
 #ifdef DEBUG
@@ -887,7 +872,7 @@ main_check_temp( double total )
 		expand_variables( PATH_TMP, tmp );
 		nativeize_path( tmp );
 		absoluteize_path( tmp );
-		to_size( &buf, total );
+		vips_buf_append_size( &buf, total );
 
 		box_yesno( NULL,
 			main_toobig_done, iwindow_true_cb, NULL,
@@ -987,12 +972,6 @@ main( int argc, char *argv[] )
 	char txt[MAX_STRSIZE];
 	VipsBuf buf = VIPS_BUF_STATIC( txt );
 
-#ifdef DEBUG_LEAK
-#ifdef PROFILE
-	g_mem_set_vtable( glib_mem_profiler_table );
-#endif /*PROFILE*/
-#endif /*DEBUG_LEAK*/
-
 #ifdef DEBUG_TIME
 	GTimer *startup_timer = g_timer_new();
 	printf( "DEBUG_TIME: startup timer zeroed ...\n" );
@@ -1130,11 +1109,6 @@ main( int argc, char *argv[] )
 		exit( 0 );
 	}
 
-#ifdef DEBUG_LEAK
-	fprintf( stderr, 
-		"*** DEBUG_LEAK is on ... will leaktest on exit\n" );
-#endif /*DEBUG_LEAK*/
-
 #ifdef DEBUG_FATAL
 	/* Set masks for debugging ... stop on any problem. 
 	 */
@@ -1144,9 +1118,6 @@ main( int argc, char *argv[] )
 		G_LOG_LEVEL_ERROR |
 		G_LOG_LEVEL_CRITICAL |
 		G_LOG_LEVEL_WARNING );
-
-	fprintf( stderr, 
-		"*** DEBUG_FATAL is on ... will abort() on first warning\n" );
 #else /*!DEBUG_FATAL*/
 #ifdef OS_WIN32 
 	/* No logging output ... on win32, log output pops up a very annoying
@@ -1503,8 +1474,13 @@ _( "A new directory has been created to hold startup, "
 		gtk_main();
 	}
 
-	if( main_option_test && expr_error_all )
-		main_error_exit( "--test: errors found" );
+	if( main_option_test ) {
+		/* Make sure we've had at least one recomp.
+		 */
+		symbol_recalculate_all_force( TRUE );
+		if( expr_error_all )
+			main_error_exit( "--test: errors found" );
+	}
 
 	/* No return from this.
 	 */
