@@ -341,7 +341,7 @@ mainw_workspace_destroy_cb( Workspace *ws, Mainw *mainw )
 	iwindow_kill( IWINDOW( mainw ) );
 }
 
-static void
+void
 mainw_find_disc( VipsBuf *buf )
 {
 	double sz = find_space( PATH_TMP );
@@ -352,12 +352,12 @@ mainw_find_disc( VipsBuf *buf )
 		char txt[MAX_STRSIZE];
 		VipsBuf buf2 = VIPS_BUF_STATIC( txt );
 
-		to_size( &buf2, sz );
+		vips_buf_append_size( &buf2, sz );
 		vips_buf_appendf( buf, _( "%s free" ), vips_buf_all( &buf2 ) );
 	}
 }
 
-static void
+void
 mainw_find_heap( VipsBuf *buf, Heap *heap )
 {
 	/* How much we can still expand the heap by ... this 
